@@ -4,12 +4,12 @@ from __future__ import unicode_literals
 import os
 import re
 
-import seg as TnTseg
+from . import seg as TnTseg
 
 data_path = os.path.join(os.path.dirname(os.path.abspath(__file__)),
                          'seg.marshal')
-segger = TnTseg.Seg()
-segger.load(data_path)
+segger = TnTseg.Seg('other')
+segger.load(data_path, True)
 
 
 def seg(sent):
